# ory_client (EXPERIMENTAL)
Documentation for all public and administrative Ory APIs. Administrative APIs can only be accessed
with a valid Personal Access Token. Public APIs are mostly used in browsers.


This Dart package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v1.1.2
- Build package: org.openapitools.codegen.languages.DartDioClientCodegen

## Requirements

* Dart 2.12.0 or later OR Flutter 1.26.0 or later
* Dio 4.0.0+

## Installation & Usage

### pub.dev
To use the package from [pub.dev](https://pub.dev), please include the following in pubspec.yaml
```yaml
dependencies:
  ory_client: 1.1.2
```

### Github
If this Dart package is published to Github, please include the following in pubspec.yaml
```yaml
dependencies:
  ory_client:
    git:
      url: https://github.com/ory/sdk.git
      #ref: main
```

### Local development
To use the package from your local drive, please include the following in pubspec.yaml
```yaml
dependencies:
  ory_client:
    path: /path/to/ory_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```dart
import 'package:ory_client/ory_client.dart';


final api = OryClient().getCourierApi();
final String id = id_example; // String | MessageID is the ID of the message.

try {
    final response = await api.getCourierMessage(id);
    print(response);
} catch on DioError (e) {
    print("Exception when calling CourierApi->getCourierMessage: $e\n");
}

```

## Documentation for API Endpoints

All URIs are relative to *https://playground.projects.oryapis.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
[*CourierApi*](doc/CourierApi.md) | [**getCourierMessage**](doc/CourierApi.md#getcouriermessage) | **GET** /admin/courier/messages/{id} | Get a Message
[*CourierApi*](doc/CourierApi.md) | [**listCourierMessages**](doc/CourierApi.md#listcouriermessages) | **GET** /admin/courier/messages | List Messages
[*FrontendApi*](doc/FrontendApi.md) | [**createBrowserLoginFlow**](doc/FrontendApi.md#createbrowserloginflow) | **GET** /self-service/login/browser | Create Login Flow for Browsers
[*FrontendApi*](doc/FrontendApi.md) | [**createBrowserLogoutFlow**](doc/FrontendApi.md#createbrowserlogoutflow) | **GET** /self-service/logout/browser | Create a Logout URL for Browsers
[*FrontendApi*](doc/FrontendApi.md) | [**createBrowserRecoveryFlow**](doc/FrontendApi.md#createbrowserrecoveryflow) | **GET** /self-service/recovery/browser | Create Recovery Flow for Browsers
[*FrontendApi*](doc/FrontendApi.md) | [**createBrowserRegistrationFlow**](doc/FrontendApi.md#createbrowserregistrationflow) | **GET** /self-service/registration/browser | Create Registration Flow for Browsers
[*FrontendApi*](doc/FrontendApi.md) | [**createBrowserSettingsFlow**](doc/FrontendApi.md#createbrowsersettingsflow) | **GET** /self-service/settings/browser | Create Settings Flow for Browsers
[*FrontendApi*](doc/FrontendApi.md) | [**createBrowserVerificationFlow**](doc/FrontendApi.md#createbrowserverificationflow) | **GET** /self-service/verification/browser | Create Verification Flow for Browser Clients
[*FrontendApi*](doc/FrontendApi.md) | [**createNativeLoginFlow**](doc/FrontendApi.md#createnativeloginflow) | **GET** /self-service/login/api | Create Login Flow for Native Apps
[*FrontendApi*](doc/FrontendApi.md) | [**createNativeRecoveryFlow**](doc/FrontendApi.md#createnativerecoveryflow) | **GET** /self-service/recovery/api | Create Recovery Flow for Native Apps
[*FrontendApi*](doc/FrontendApi.md) | [**createNativeRegistrationFlow**](doc/FrontendApi.md#createnativeregistrationflow) | **GET** /self-service/registration/api | Create Registration Flow for Native Apps
[*FrontendApi*](doc/FrontendApi.md) | [**createNativeSettingsFlow**](doc/FrontendApi.md#createnativesettingsflow) | **GET** /self-service/settings/api | Create Settings Flow for Native Apps
[*FrontendApi*](doc/FrontendApi.md) | [**createNativeVerificationFlow**](doc/FrontendApi.md#createnativeverificationflow) | **GET** /self-service/verification/api | Create Verification Flow for Native Apps
[*FrontendApi*](doc/FrontendApi.md) | [**disableMyOtherSessions**](doc/FrontendApi.md#disablemyothersessions) | **DELETE** /sessions | Disable my other sessions
[*FrontendApi*](doc/FrontendApi.md) | [**disableMySession**](doc/FrontendApi.md#disablemysession) | **DELETE** /sessions/{id} | Disable one of my sessions
[*FrontendApi*](doc/FrontendApi.md) | [**getFlowError**](doc/FrontendApi.md#getflowerror) | **GET** /self-service/errors | Get User-Flow Errors
[*FrontendApi*](doc/FrontendApi.md) | [**getLoginFlow**](doc/FrontendApi.md#getloginflow) | **GET** /self-service/login/flows | Get Login Flow
[*FrontendApi*](doc/FrontendApi.md) | [**getRecoveryFlow**](doc/FrontendApi.md#getrecoveryflow) | **GET** /self-service/recovery/flows | Get Recovery Flow
[*FrontendApi*](doc/FrontendApi.md) | [**getRegistrationFlow**](doc/FrontendApi.md#getregistrationflow) | **GET** /self-service/registration/flows | Get Registration Flow
[*FrontendApi*](doc/FrontendApi.md) | [**getSettingsFlow**](doc/FrontendApi.md#getsettingsflow) | **GET** /self-service/settings/flows | Get Settings Flow
[*FrontendApi*](doc/FrontendApi.md) | [**getVerificationFlow**](doc/FrontendApi.md#getverificationflow) | **GET** /self-service/verification/flows | Get Verification Flow
[*FrontendApi*](doc/FrontendApi.md) | [**getWebAuthnJavaScript**](doc/FrontendApi.md#getwebauthnjavascript) | **GET** /.well-known/ory/webauthn.js | Get WebAuthn JavaScript
[*FrontendApi*](doc/FrontendApi.md) | [**listMySessions**](doc/FrontendApi.md#listmysessions) | **GET** /sessions | Get My Active Sessions
[*FrontendApi*](doc/FrontendApi.md) | [**performNativeLogout**](doc/FrontendApi.md#performnativelogout) | **DELETE** /self-service/logout/api | Perform Logout for Native Apps
[*FrontendApi*](doc/FrontendApi.md) | [**toSession**](doc/FrontendApi.md#tosession) | **GET** /sessions/whoami | Check Who the Current HTTP Session Belongs To
[*FrontendApi*](doc/FrontendApi.md) | [**updateLoginFlow**](doc/FrontendApi.md#updateloginflow) | **POST** /self-service/login | Submit a Login Flow
[*FrontendApi*](doc/FrontendApi.md) | [**updateLogoutFlow**](doc/FrontendApi.md#updatelogoutflow) | **GET** /self-service/logout | Update Logout Flow
[*FrontendApi*](doc/FrontendApi.md) | [**updateRecoveryFlow**](doc/FrontendApi.md#updaterecoveryflow) | **POST** /self-service/recovery | Complete Recovery Flow
[*FrontendApi*](doc/FrontendApi.md) | [**updateRegistrationFlow**](doc/FrontendApi.md#updateregistrationflow) | **POST** /self-service/registration | Update Registration Flow
[*FrontendApi*](doc/FrontendApi.md) | [**updateSettingsFlow**](doc/FrontendApi.md#updatesettingsflow) | **POST** /self-service/settings | Complete Settings Flow
[*FrontendApi*](doc/FrontendApi.md) | [**updateVerificationFlow**](doc/FrontendApi.md#updateverificationflow) | **POST** /self-service/verification | Complete Verification Flow
[*IdentityApi*](doc/IdentityApi.md) | [**createIdentity**](doc/IdentityApi.md#createidentity) | **POST** /admin/identities | Create an Identity
[*IdentityApi*](doc/IdentityApi.md) | [**createRecoveryCodeForIdentity**](doc/IdentityApi.md#createrecoverycodeforidentity) | **POST** /admin/recovery/code | Create a Recovery Code
[*IdentityApi*](doc/IdentityApi.md) | [**createRecoveryLinkForIdentity**](doc/IdentityApi.md#createrecoverylinkforidentity) | **POST** /admin/recovery/link | Create a Recovery Link
[*IdentityApi*](doc/IdentityApi.md) | [**deleteIdentity**](doc/IdentityApi.md#deleteidentity) | **DELETE** /admin/identities/{id} | Delete an Identity
[*IdentityApi*](doc/IdentityApi.md) | [**deleteIdentitySessions**](doc/IdentityApi.md#deleteidentitysessions) | **DELETE** /admin/identities/{id}/sessions | Delete &amp; Invalidate an Identity&#39;s Sessions
[*IdentityApi*](doc/IdentityApi.md) | [**disableSession**](doc/IdentityApi.md#disablesession) | **DELETE** /admin/sessions/{id} | Deactivate a Session
[*IdentityApi*](doc/IdentityApi.md) | [**extendSession**](doc/IdentityApi.md#extendsession) | **PATCH** /admin/sessions/{id}/extend | Extend a Session
[*IdentityApi*](doc/IdentityApi.md) | [**getIdentity**](doc/IdentityApi.md#getidentity) | **GET** /admin/identities/{id} | Get an Identity
[*IdentityApi*](doc/IdentityApi.md) | [**getIdentitySchema**](doc/IdentityApi.md#getidentityschema) | **GET** /schemas/{id} | Get Identity JSON Schema
[*IdentityApi*](doc/IdentityApi.md) | [**getSession**](doc/IdentityApi.md#getsession) | **GET** /admin/sessions/{id} | This endpoint returns the session object with expandables specified.
[*IdentityApi*](doc/IdentityApi.md) | [**listIdentities**](doc/IdentityApi.md#listidentities) | **GET** /admin/identities | List Identities
[*IdentityApi*](doc/IdentityApi.md) | [**listIdentitySchemas**](doc/IdentityApi.md#listidentityschemas) | **GET** /schemas | Get all Identity Schemas
[*IdentityApi*](doc/IdentityApi.md) | [**listIdentitySessions**](doc/IdentityApi.md#listidentitysessions) | **GET** /admin/identities/{id}/sessions | List an Identity&#39;s Sessions
[*IdentityApi*](doc/IdentityApi.md) | [**listSessions**](doc/IdentityApi.md#listsessions) | **GET** /admin/sessions | List All Sessions
[*IdentityApi*](doc/IdentityApi.md) | [**patchIdentity**](doc/IdentityApi.md#patchidentity) | **PATCH** /admin/identities/{id} | Patch an Identity
[*IdentityApi*](doc/IdentityApi.md) | [**updateIdentity**](doc/IdentityApi.md#updateidentity) | **PUT** /admin/identities/{id} | Update an Identity
[*JwkApi*](doc/JwkApi.md) | [**createJsonWebKeySet**](doc/JwkApi.md#createjsonwebkeyset) | **POST** /admin/keys/{set} | Create JSON Web Key
[*JwkApi*](doc/JwkApi.md) | [**deleteJsonWebKey**](doc/JwkApi.md#deletejsonwebkey) | **DELETE** /admin/keys/{set}/{kid} | Delete JSON Web Key
[*JwkApi*](doc/JwkApi.md) | [**deleteJsonWebKeySet**](doc/JwkApi.md#deletejsonwebkeyset) | **DELETE** /admin/keys/{set} | Delete JSON Web Key Set
[*JwkApi*](doc/JwkApi.md) | [**getJsonWebKey**](doc/JwkApi.md#getjsonwebkey) | **GET** /admin/keys/{set}/{kid} | Get JSON Web Key
[*JwkApi*](doc/JwkApi.md) | [**getJsonWebKeySet**](doc/JwkApi.md#getjsonwebkeyset) | **GET** /admin/keys/{set} | Retrieve a JSON Web Key Set
[*JwkApi*](doc/JwkApi.md) | [**setJsonWebKey**](doc/JwkApi.md#setjsonwebkey) | **PUT** /admin/keys/{set}/{kid} | Set JSON Web Key
[*JwkApi*](doc/JwkApi.md) | [**setJsonWebKeySet**](doc/JwkApi.md#setjsonwebkeyset) | **PUT** /admin/keys/{set} | Update a JSON Web Key Set
[*MetadataApi*](doc/MetadataApi.md) | [**getVersion**](doc/MetadataApi.md#getversion) | **GET** /version | Return Running Software Version.
[*MetadataApi*](doc/MetadataApi.md) | [**isAlive**](doc/MetadataApi.md#isalive) | **GET** /health/alive | Check HTTP Server Status
[*MetadataApi*](doc/MetadataApi.md) | [**isReady**](doc/MetadataApi.md#isready) | **GET** /health/ready | Check HTTP Server and Database Status
[*OAuth2Api*](doc/OAuth2Api.md) | [**acceptOAuth2ConsentRequest**](doc/OAuth2Api.md#acceptoauth2consentrequest) | **PUT** /admin/oauth2/auth/requests/consent/accept | Accept OAuth 2.0 Consent Request
[*OAuth2Api*](doc/OAuth2Api.md) | [**acceptOAuth2LoginRequest**](doc/OAuth2Api.md#acceptoauth2loginrequest) | **PUT** /admin/oauth2/auth/requests/login/accept | Accept OAuth 2.0 Login Request
[*OAuth2Api*](doc/OAuth2Api.md) | [**acceptOAuth2LogoutRequest**](doc/OAuth2Api.md#acceptoauth2logoutrequest) | **PUT** /admin/oauth2/auth/requests/logout/accept | Accept OAuth 2.0 Session Logout Request
[*OAuth2Api*](doc/OAuth2Api.md) | [**createOAuth2Client**](doc/OAuth2Api.md#createoauth2client) | **POST** /admin/clients | Create OAuth 2.0 Client
[*OAuth2Api*](doc/OAuth2Api.md) | [**deleteOAuth2Client**](doc/OAuth2Api.md#deleteoauth2client) | **DELETE** /admin/clients/{id} | Delete OAuth 2.0 Client
[*OAuth2Api*](doc/OAuth2Api.md) | [**deleteOAuth2Token**](doc/OAuth2Api.md#deleteoauth2token) | **DELETE** /admin/oauth2/tokens | Delete OAuth 2.0 Access Tokens from specific OAuth 2.0 Client
[*OAuth2Api*](doc/OAuth2Api.md) | [**deleteTrustedOAuth2JwtGrantIssuer**](doc/OAuth2Api.md#deletetrustedoauth2jwtgrantissuer) | **DELETE** /admin/trust/grants/jwt-bearer/issuers/{id} | Delete Trusted OAuth2 JWT Bearer Grant Type Issuer
[*OAuth2Api*](doc/OAuth2Api.md) | [**getOAuth2Client**](doc/OAuth2Api.md#getoauth2client) | **GET** /admin/clients/{id} | Get an OAuth 2.0 Client
[*OAuth2Api*](doc/OAuth2Api.md) | [**getOAuth2ConsentRequest**](doc/OAuth2Api.md#getoauth2consentrequest) | **GET** /admin/oauth2/auth/requests/consent | Get OAuth 2.0 Consent Request
[*OAuth2Api*](doc/OAuth2Api.md) | [**getOAuth2LoginRequest**](doc/OAuth2Api.md#getoauth2loginrequest) | **GET** /admin/oauth2/auth/requests/login | Get OAuth 2.0 Login Request
[*OAuth2Api*](doc/OAuth2Api.md) | [**getOAuth2LogoutRequest**](doc/OAuth2Api.md#getoauth2logoutrequest) | **GET** /admin/oauth2/auth/requests/logout | Get OAuth 2.0 Session Logout Request
[*OAuth2Api*](doc/OAuth2Api.md) | [**getTrustedOAuth2JwtGrantIssuer**](doc/OAuth2Api.md#gettrustedoauth2jwtgrantissuer) | **GET** /admin/trust/grants/jwt-bearer/issuers/{id} | Get Trusted OAuth2 JWT Bearer Grant Type Issuer
[*OAuth2Api*](doc/OAuth2Api.md) | [**introspectOAuth2Token**](doc/OAuth2Api.md#introspectoauth2token) | **POST** /admin/oauth2/introspect | Introspect OAuth2 Access and Refresh Tokens
[*OAuth2Api*](doc/OAuth2Api.md) | [**listOAuth2Clients**](doc/OAuth2Api.md#listoauth2clients) | **GET** /admin/clients | List OAuth 2.0 Clients
[*OAuth2Api*](doc/OAuth2Api.md) | [**listOAuth2ConsentSessions**](doc/OAuth2Api.md#listoauth2consentsessions) | **GET** /admin/oauth2/auth/sessions/consent | List OAuth 2.0 Consent Sessions of a Subject
[*OAuth2Api*](doc/OAuth2Api.md) | [**listTrustedOAuth2JwtGrantIssuers**](doc/OAuth2Api.md#listtrustedoauth2jwtgrantissuers) | **GET** /admin/trust/grants/jwt-bearer/issuers | List Trusted OAuth2 JWT Bearer Grant Type Issuers
[*OAuth2Api*](doc/OAuth2Api.md) | [**oAuth2Authorize**](doc/OAuth2Api.md#oauth2authorize) | **GET** /oauth2/auth | OAuth 2.0 Authorize Endpoint
[*OAuth2Api*](doc/OAuth2Api.md) | [**oauth2TokenExchange**](doc/OAuth2Api.md#oauth2tokenexchange) | **POST** /oauth2/token | The OAuth 2.0 Token Endpoint
[*OAuth2Api*](doc/OAuth2Api.md) | [**patchOAuth2Client**](doc/OAuth2Api.md#patchoauth2client) | **PATCH** /admin/clients/{id} | Patch OAuth 2.0 Client
[*OAuth2Api*](doc/OAuth2Api.md) | [**rejectOAuth2ConsentRequest**](doc/OAuth2Api.md#rejectoauth2consentrequest) | **PUT** /admin/oauth2/auth/requests/consent/reject | Reject OAuth 2.0 Consent Request
[*OAuth2Api*](doc/OAuth2Api.md) | [**rejectOAuth2LoginRequest**](doc/OAuth2Api.md#rejectoauth2loginrequest) | **PUT** /admin/oauth2/auth/requests/login/reject | Reject OAuth 2.0 Login Request
[*OAuth2Api*](doc/OAuth2Api.md) | [**rejectOAuth2LogoutRequest**](doc/OAuth2Api.md#rejectoauth2logoutrequest) | **PUT** /admin/oauth2/auth/requests/logout/reject | Reject OAuth 2.0 Session Logout Request
[*OAuth2Api*](doc/OAuth2Api.md) | [**revokeOAuth2ConsentSessions**](doc/OAuth2Api.md#revokeoauth2consentsessions) | **DELETE** /admin/oauth2/auth/sessions/consent | Revoke OAuth 2.0 Consent Sessions of a Subject
[*OAuth2Api*](doc/OAuth2Api.md) | [**revokeOAuth2LoginSessions**](doc/OAuth2Api.md#revokeoauth2loginsessions) | **DELETE** /admin/oauth2/auth/sessions/login | Revokes All OAuth 2.0 Login Sessions of a Subject
[*OAuth2Api*](doc/OAuth2Api.md) | [**revokeOAuth2Token**](doc/OAuth2Api.md#revokeoauth2token) | **POST** /oauth2/revoke | Revoke OAuth 2.0 Access or Refresh Token
[*OAuth2Api*](doc/OAuth2Api.md) | [**setOAuth2Client**](doc/OAuth2Api.md#setoauth2client) | **PUT** /admin/clients/{id} | Set OAuth 2.0 Client
[*OAuth2Api*](doc/OAuth2Api.md) | [**setOAuth2ClientLifespans**](doc/OAuth2Api.md#setoauth2clientlifespans) | **PUT** /admin/clients/{id}/lifespans | Set OAuth2 Client Token Lifespans
[*OAuth2Api*](doc/OAuth2Api.md) | [**trustOAuth2JwtGrantIssuer**](doc/OAuth2Api.md#trustoauth2jwtgrantissuer) | **POST** /admin/trust/grants/jwt-bearer/issuers | Trust OAuth2 JWT Bearer Grant Type Issuer
[*OidcApi*](doc/OidcApi.md) | [**createOidcDynamicClient**](doc/OidcApi.md#createoidcdynamicclient) | **POST** /oauth2/register | Register OAuth2 Client using OpenID Dynamic Client Registration
[*OidcApi*](doc/OidcApi.md) | [**deleteOidcDynamicClient**](doc/OidcApi.md#deleteoidcdynamicclient) | **DELETE** /oauth2/register/{id} | Delete OAuth 2.0 Client using the OpenID Dynamic Client Registration Management Protocol
[*OidcApi*](doc/OidcApi.md) | [**discoverOidcConfiguration**](doc/OidcApi.md#discoveroidcconfiguration) | **GET** /.well-known/openid-configuration | OpenID Connect Discovery
[*OidcApi*](doc/OidcApi.md) | [**getOidcDynamicClient**](doc/OidcApi.md#getoidcdynamicclient) | **GET** /oauth2/register/{id} | Get OAuth2 Client using OpenID Dynamic Client Registration
[*OidcApi*](doc/OidcApi.md) | [**getOidcUserInfo**](doc/OidcApi.md#getoidcuserinfo) | **GET** /userinfo | OpenID Connect Userinfo
[*OidcApi*](doc/OidcApi.md) | [**revokeOidcSession**](doc/OidcApi.md#revokeoidcsession) | **GET** /oauth2/sessions/logout | OpenID Connect Front- and Back-channel Enabled Logout
[*OidcApi*](doc/OidcApi.md) | [**setOidcDynamicClient**](doc/OidcApi.md#setoidcdynamicclient) | **PUT** /oauth2/register/{id} | Set OAuth2 Client using OpenID Dynamic Client Registration
[*PermissionApi*](doc/PermissionApi.md) | [**checkPermission**](doc/PermissionApi.md#checkpermission) | **GET** /relation-tuples/check/openapi | Check a permission
[*PermissionApi*](doc/PermissionApi.md) | [**checkPermissionOrError**](doc/PermissionApi.md#checkpermissionorerror) | **GET** /relation-tuples/check | Check a permission
[*PermissionApi*](doc/PermissionApi.md) | [**expandPermissions**](doc/PermissionApi.md#expandpermissions) | **GET** /relation-tuples/expand | Expand a Relationship into permissions.
[*PermissionApi*](doc/PermissionApi.md) | [**postCheckPermission**](doc/PermissionApi.md#postcheckpermission) | **POST** /relation-tuples/check/openapi | Check a permission
[*PermissionApi*](doc/PermissionApi.md) | [**postCheckPermissionOrError**](doc/PermissionApi.md#postcheckpermissionorerror) | **POST** /relation-tuples/check | Check a permission
[*ProjectApi*](doc/ProjectApi.md) | [**createProject**](doc/ProjectApi.md#createproject) | **POST** /projects | Create a Project
[*ProjectApi*](doc/ProjectApi.md) | [**createProjectApiKey**](doc/ProjectApi.md#createprojectapikey) | **POST** /projects/{project}/tokens | Create project API token
[*ProjectApi*](doc/ProjectApi.md) | [**deleteProjectApiKey**](doc/ProjectApi.md#deleteprojectapikey) | **DELETE** /projects/{project}/tokens/{token_id} | Delete project API token
[*ProjectApi*](doc/ProjectApi.md) | [**getActiveProjectInConsole**](doc/ProjectApi.md#getactiveprojectinconsole) | **GET** /console/active/project | Returns the Ory Network Project selected in the Ory Network Console
[*ProjectApi*](doc/ProjectApi.md) | [**getProject**](doc/ProjectApi.md#getproject) | **GET** /projects/{project_id} | Get a Project
[*ProjectApi*](doc/ProjectApi.md) | [**getProjectMembers**](doc/ProjectApi.md#getprojectmembers) | **GET** /projects/{project_id}/members | Get all members associated with this project
[*ProjectApi*](doc/ProjectApi.md) | [**listProjectApiKeys**](doc/ProjectApi.md#listprojectapikeys) | **GET** /projects/{project}/tokens | List a project&#39;s API Tokens
[*ProjectApi*](doc/ProjectApi.md) | [**listProjects**](doc/ProjectApi.md#listprojects) | **GET** /projects | List All Projects
[*ProjectApi*](doc/ProjectApi.md) | [**patchProject**](doc/ProjectApi.md#patchproject) | **PATCH** /projects/{project_id} | Patch an Ory Network Project Configuration
[*ProjectApi*](doc/ProjectApi.md) | [**purgeProject**](doc/ProjectApi.md#purgeproject) | **DELETE** /projects/{project_id} | Irrecoverably purge a project
[*ProjectApi*](doc/ProjectApi.md) | [**removeProjectMember**](doc/ProjectApi.md#removeprojectmember) | **DELETE** /projects/{project_id}/members/{member_id} | Remove a member associated with this project
[*ProjectApi*](doc/ProjectApi.md) | [**setActiveProjectInConsole**](doc/ProjectApi.md#setactiveprojectinconsole) | **PUT** /console/active/project | Sets the Ory Network Project active in the Ory Network Console
[*ProjectApi*](doc/ProjectApi.md) | [**setProject**](doc/ProjectApi.md#setproject) | **PUT** /projects/{project_id} | Update an Ory Network Project Configuration
[*RelationshipApi*](doc/RelationshipApi.md) | [**checkOplSyntax**](doc/RelationshipApi.md#checkoplsyntax) | **POST** /opl/syntax/check | Check the syntax of an OPL file
[*RelationshipApi*](doc/RelationshipApi.md) | [**createRelationship**](doc/RelationshipApi.md#createrelationship) | **PUT** /admin/relation-tuples | Create a Relationship
[*RelationshipApi*](doc/RelationshipApi.md) | [**deleteRelationships**](doc/RelationshipApi.md#deleterelationships) | **DELETE** /admin/relation-tuples | Delete Relationships
[*RelationshipApi*](doc/RelationshipApi.md) | [**getRelationships**](doc/RelationshipApi.md#getrelationships) | **GET** /relation-tuples | Query relationships
[*RelationshipApi*](doc/RelationshipApi.md) | [**listRelationshipNamespaces**](doc/RelationshipApi.md#listrelationshipnamespaces) | **GET** /namespaces | Query namespaces
[*RelationshipApi*](doc/RelationshipApi.md) | [**patchRelationships**](doc/RelationshipApi.md#patchrelationships) | **PATCH** /admin/relation-tuples | Patch Multiple Relationships
[*WellknownApi*](doc/WellknownApi.md) | [**discoverJsonWebKeys**](doc/WellknownApi.md#discoverjsonwebkeys) | **GET** /.well-known/jwks.json | Discover Well-Known JSON Web Keys


## Documentation For Models

 - [AcceptOAuth2ConsentRequest](doc/AcceptOAuth2ConsentRequest.md)
 - [AcceptOAuth2ConsentRequestSession](doc/AcceptOAuth2ConsentRequestSession.md)
 - [AcceptOAuth2LoginRequest](doc/AcceptOAuth2LoginRequest.md)
 - [ActiveProjectInConsole](doc/ActiveProjectInConsole.md)
 - [AuthenticatorAssuranceLevel](doc/AuthenticatorAssuranceLevel.md)
 - [CheckOplSyntaxResult](doc/CheckOplSyntaxResult.md)
 - [CheckPermissionResult](doc/CheckPermissionResult.md)
 - [CloudAccount](doc/CloudAccount.md)
 - [CourierMessageStatus](doc/CourierMessageStatus.md)
 - [CourierMessageType](doc/CourierMessageType.md)
 - [CreateCustomDomainBody](doc/CreateCustomDomainBody.md)
 - [CreateIdentityBody](doc/CreateIdentityBody.md)
 - [CreateJsonWebKeySet](doc/CreateJsonWebKeySet.md)
 - [CreateProjectApiKeyRequest](doc/CreateProjectApiKeyRequest.md)
 - [CreateProjectBody](doc/CreateProjectBody.md)
 - [CreateProjectBranding](doc/CreateProjectBranding.md)
 - [CreateProjectInvite](doc/CreateProjectInvite.md)
 - [CreateRecoveryCodeForIdentityBody](doc/CreateRecoveryCodeForIdentityBody.md)
 - [CreateRecoveryLinkForIdentityBody](doc/CreateRecoveryLinkForIdentityBody.md)
 - [CreateRelationshipBody](doc/CreateRelationshipBody.md)
 - [CreateSubscriptionBody](doc/CreateSubscriptionBody.md)
 - [CustomDomain](doc/CustomDomain.md)
 - [CustomDomainQuota](doc/CustomDomainQuota.md)
 - [DeleteMySessionsCount](doc/DeleteMySessionsCount.md)
 - [ErrorAuthenticatorAssuranceLevelNotSatisfied](doc/ErrorAuthenticatorAssuranceLevelNotSatisfied.md)
 - [ErrorBrowserLocationChangeRequired](doc/ErrorBrowserLocationChangeRequired.md)
 - [ErrorFlowReplaced](doc/ErrorFlowReplaced.md)
 - [ErrorGeneric](doc/ErrorGeneric.md)
 - [ErrorOAuth2](doc/ErrorOAuth2.md)
 - [ExpandedPermissionTree](doc/ExpandedPermissionTree.md)
 - [FlowError](doc/FlowError.md)
 - [GenericError](doc/GenericError.md)
 - [GenericErrorContent](doc/GenericErrorContent.md)
 - [GetManagedIdentitySchemaLocation](doc/GetManagedIdentitySchemaLocation.md)
 - [GetVersion200Response](doc/GetVersion200Response.md)
 - [HealthNotReadyStatus](doc/HealthNotReadyStatus.md)
 - [HealthStatus](doc/HealthStatus.md)
 - [Identity](doc/Identity.md)
 - [IdentityCredentials](doc/IdentityCredentials.md)
 - [IdentityCredentialsOidc](doc/IdentityCredentialsOidc.md)
 - [IdentityCredentialsOidcProvider](doc/IdentityCredentialsOidcProvider.md)
 - [IdentityCredentialsPassword](doc/IdentityCredentialsPassword.md)
 - [IdentityCredentialsType](doc/IdentityCredentialsType.md)
 - [IdentitySchemaContainer](doc/IdentitySchemaContainer.md)
 - [IdentitySchemaPreset](doc/IdentitySchemaPreset.md)
 - [IdentityState](doc/IdentityState.md)
 - [IdentityWithCredentials](doc/IdentityWithCredentials.md)
 - [IdentityWithCredentialsOidc](doc/IdentityWithCredentialsOidc.md)
 - [IdentityWithCredentialsOidcConfig](doc/IdentityWithCredentialsOidcConfig.md)
 - [IdentityWithCredentialsOidcConfigProvider](doc/IdentityWithCredentialsOidcConfigProvider.md)
 - [IdentityWithCredentialsPassword](doc/IdentityWithCredentialsPassword.md)
 - [IdentityWithCredentialsPasswordConfig](doc/IdentityWithCredentialsPasswordConfig.md)
 - [InternalGetProjectBrandingBody](doc/InternalGetProjectBrandingBody.md)
 - [InternalIsOwnerForProjectBySlugBody](doc/InternalIsOwnerForProjectBySlugBody.md)
 - [InternalProvisionMockSubscription](doc/InternalProvisionMockSubscription.md)
 - [IntrospectedOAuth2Token](doc/IntrospectedOAuth2Token.md)
 - [InviteQuota](doc/InviteQuota.md)
 - [IsOwnerForProjectBySlug](doc/IsOwnerForProjectBySlug.md)
 - [IsReady200Response](doc/IsReady200Response.md)
 - [IsReady503Response](doc/IsReady503Response.md)
 - [JsonPatch](doc/JsonPatch.md)
 - [JsonWebKey](doc/JsonWebKey.md)
 - [JsonWebKeySet](doc/JsonWebKeySet.md)
 - [KetoNamespace](doc/KetoNamespace.md)
 - [LoginFlow](doc/LoginFlow.md)
 - [LogoutFlow](doc/LogoutFlow.md)
 - [ManagedIdentitySchema](doc/ManagedIdentitySchema.md)
 - [ManagedIdentitySchemaValidationResult](doc/ManagedIdentitySchemaValidationResult.md)
 - [Message](doc/Message.md)
 - [MessageDispatch](doc/MessageDispatch.md)
 - [Namespace](doc/Namespace.md)
 - [NeedsPrivilegedSessionError](doc/NeedsPrivilegedSessionError.md)
 - [NormalizedProject](doc/NormalizedProject.md)
 - [NormalizedProjectRevision](doc/NormalizedProjectRevision.md)
 - [NormalizedProjectRevisionHook](doc/NormalizedProjectRevisionHook.md)
 - [NormalizedProjectRevisionIdentitySchema](doc/NormalizedProjectRevisionIdentitySchema.md)
 - [NormalizedProjectRevisionThirdPartyProvider](doc/NormalizedProjectRevisionThirdPartyProvider.md)
 - [NullPlan](doc/NullPlan.md)
 - [OAuth2Client](doc/OAuth2Client.md)
 - [OAuth2ClientTokenLifespans](doc/OAuth2ClientTokenLifespans.md)
 - [OAuth2ConsentRequest](doc/OAuth2ConsentRequest.md)
 - [OAuth2ConsentRequestOpenIDConnectContext](doc/OAuth2ConsentRequestOpenIDConnectContext.md)
 - [OAuth2ConsentSession](doc/OAuth2ConsentSession.md)
 - [OAuth2ConsentSessionExpiresAt](doc/OAuth2ConsentSessionExpiresAt.md)
 - [OAuth2LoginRequest](doc/OAuth2LoginRequest.md)
 - [OAuth2LogoutRequest](doc/OAuth2LogoutRequest.md)
 - [OAuth2RedirectTo](doc/OAuth2RedirectTo.md)
 - [OAuth2TokenExchange](doc/OAuth2TokenExchange.md)
 - [OidcConfiguration](doc/OidcConfiguration.md)
 - [OidcUserInfo](doc/OidcUserInfo.md)
 - [Pagination](doc/Pagination.md)
 - [PaginationHeaders](doc/PaginationHeaders.md)
 - [ParseError](doc/ParseError.md)
 - [PerformNativeLogoutBody](doc/PerformNativeLogoutBody.md)
 - [PostCheckPermissionBody](doc/PostCheckPermissionBody.md)
 - [PostCheckPermissionOrErrorBody](doc/PostCheckPermissionOrErrorBody.md)
 - [Project](doc/Project.md)
 - [ProjectApiKey](doc/ProjectApiKey.md)
 - [ProjectBranding](doc/ProjectBranding.md)
 - [ProjectBrandingColors](doc/ProjectBrandingColors.md)
 - [ProjectBrandingTheme](doc/ProjectBrandingTheme.md)
 - [ProjectHost](doc/ProjectHost.md)
 - [ProjectInvite](doc/ProjectInvite.md)
 - [ProjectMetadata](doc/ProjectMetadata.md)
 - [ProjectServiceIdentity](doc/ProjectServiceIdentity.md)
 - [ProjectServiceOAuth2](doc/ProjectServiceOAuth2.md)
 - [ProjectServicePermission](doc/ProjectServicePermission.md)
 - [ProjectServices](doc/ProjectServices.md)
 - [QuotaBrandingThemes](doc/QuotaBrandingThemes.md)
 - [RecoveryCodeForIdentity](doc/RecoveryCodeForIdentity.md)
 - [RecoveryFlow](doc/RecoveryFlow.md)
 - [RecoveryFlowState](doc/RecoveryFlowState.md)
 - [RecoveryIdentityAddress](doc/RecoveryIdentityAddress.md)
 - [RecoveryLinkForIdentity](doc/RecoveryLinkForIdentity.md)
 - [RegistrationFlow](doc/RegistrationFlow.md)
 - [RejectOAuth2Request](doc/RejectOAuth2Request.md)
 - [RelationQuery](doc/RelationQuery.md)
 - [Relationship](doc/Relationship.md)
 - [RelationshipNamespaces](doc/RelationshipNamespaces.md)
 - [RelationshipPatch](doc/RelationshipPatch.md)
 - [Relationships](doc/Relationships.md)
 - [SchemaPatch](doc/SchemaPatch.md)
 - [SelfServiceFlowExpiredError](doc/SelfServiceFlowExpiredError.md)
 - [Session](doc/Session.md)
 - [SessionAuthenticationMethod](doc/SessionAuthenticationMethod.md)
 - [SessionCachingQuota](doc/SessionCachingQuota.md)
 - [SessionDevice](doc/SessionDevice.md)
 - [SetActiveProjectInConsoleBody](doc/SetActiveProjectInConsoleBody.md)
 - [SetCustomDomainBody](doc/SetCustomDomainBody.md)
 - [SetProject](doc/SetProject.md)
 - [SetProjectBrandingThemeBody](doc/SetProjectBrandingThemeBody.md)
 - [SettingsFlow](doc/SettingsFlow.md)
 - [SettingsFlowState](doc/SettingsFlowState.md)
 - [SourcePosition](doc/SourcePosition.md)
 - [StripeCustomer](doc/StripeCustomer.md)
 - [SubjectSet](doc/SubjectSet.md)
 - [Subscription](doc/Subscription.md)
 - [SuccessfulNativeLogin](doc/SuccessfulNativeLogin.md)
 - [SuccessfulNativeRegistration](doc/SuccessfulNativeRegistration.md)
 - [SuccessfulProjectUpdate](doc/SuccessfulProjectUpdate.md)
 - [TokenPagination](doc/TokenPagination.md)
 - [TokenPaginationHeaders](doc/TokenPaginationHeaders.md)
 - [TokenPaginationRequestParameters](doc/TokenPaginationRequestParameters.md)
 - [TokenPaginationResponseHeaders](doc/TokenPaginationResponseHeaders.md)
 - [TrustOAuth2JwtGrantIssuer](doc/TrustOAuth2JwtGrantIssuer.md)
 - [TrustedOAuth2JwtGrantIssuer](doc/TrustedOAuth2JwtGrantIssuer.md)
 - [TrustedOAuth2JwtGrantJsonWebKey](doc/TrustedOAuth2JwtGrantJsonWebKey.md)
 - [UiContainer](doc/UiContainer.md)
 - [UiNode](doc/UiNode.md)
 - [UiNodeAnchorAttributes](doc/UiNodeAnchorAttributes.md)
 - [UiNodeAttributes](doc/UiNodeAttributes.md)
 - [UiNodeImageAttributes](doc/UiNodeImageAttributes.md)
 - [UiNodeInputAttributes](doc/UiNodeInputAttributes.md)
 - [UiNodeMeta](doc/UiNodeMeta.md)
 - [UiNodeScriptAttributes](doc/UiNodeScriptAttributes.md)
 - [UiNodeTextAttributes](doc/UiNodeTextAttributes.md)
 - [UiText](doc/UiText.md)
 - [UpdateIdentityBody](doc/UpdateIdentityBody.md)
 - [UpdateLoginFlowBody](doc/UpdateLoginFlowBody.md)
 - [UpdateLoginFlowWithLookupSecretMethod](doc/UpdateLoginFlowWithLookupSecretMethod.md)
 - [UpdateLoginFlowWithOidcMethod](doc/UpdateLoginFlowWithOidcMethod.md)
 - [UpdateLoginFlowWithPasswordMethod](doc/UpdateLoginFlowWithPasswordMethod.md)
 - [UpdateLoginFlowWithTotpMethod](doc/UpdateLoginFlowWithTotpMethod.md)
 - [UpdateLoginFlowWithWebAuthnMethod](doc/UpdateLoginFlowWithWebAuthnMethod.md)
 - [UpdateRecoveryFlowBody](doc/UpdateRecoveryFlowBody.md)
 - [UpdateRecoveryFlowWithCodeMethod](doc/UpdateRecoveryFlowWithCodeMethod.md)
 - [UpdateRecoveryFlowWithLinkMethod](doc/UpdateRecoveryFlowWithLinkMethod.md)
 - [UpdateRegistrationFlowBody](doc/UpdateRegistrationFlowBody.md)
 - [UpdateRegistrationFlowWithOidcMethod](doc/UpdateRegistrationFlowWithOidcMethod.md)
 - [UpdateRegistrationFlowWithPasswordMethod](doc/UpdateRegistrationFlowWithPasswordMethod.md)
 - [UpdateRegistrationFlowWithWebAuthnMethod](doc/UpdateRegistrationFlowWithWebAuthnMethod.md)
 - [UpdateSettingsFlowBody](doc/UpdateSettingsFlowBody.md)
 - [UpdateSettingsFlowWithLookupMethod](doc/UpdateSettingsFlowWithLookupMethod.md)
 - [UpdateSettingsFlowWithOidcMethod](doc/UpdateSettingsFlowWithOidcMethod.md)
 - [UpdateSettingsFlowWithPasswordMethod](doc/UpdateSettingsFlowWithPasswordMethod.md)
 - [UpdateSettingsFlowWithProfileMethod](doc/UpdateSettingsFlowWithProfileMethod.md)
 - [UpdateSettingsFlowWithTotpMethod](doc/UpdateSettingsFlowWithTotpMethod.md)
 - [UpdateSettingsFlowWithWebAuthnMethod](doc/UpdateSettingsFlowWithWebAuthnMethod.md)
 - [UpdateSubscriptionBody](doc/UpdateSubscriptionBody.md)
 - [UpdateVerificationFlowBody](doc/UpdateVerificationFlowBody.md)
 - [UpdateVerificationFlowWithCodeMethodBody](doc/UpdateVerificationFlowWithCodeMethodBody.md)
 - [UpdateVerificationFlowWithLinkMethod](doc/UpdateVerificationFlowWithLinkMethod.md)
 - [VerifiableIdentityAddress](doc/VerifiableIdentityAddress.md)
 - [VerificationFlow](doc/VerificationFlow.md)
 - [VerificationFlowState](doc/VerificationFlowState.md)
 - [Version](doc/Version.md)
 - [Warning](doc/Warning.md)


## Documentation For Authorization


## basic

- **Type**: HTTP basic authentication

## bearer

- **Type**: HTTP basic authentication

## oauth2

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://hydra.demo.ory.sh/oauth2/auth
- **Scopes**: 
 - **offline**: A scope required when requesting refresh tokens (alias for `offline_access`)
 - **offline_access**: A scope required when requesting refresh tokens
 - **openid**: Request an OpenID Connect ID Token

## oryAccessToken

- **Type**: HTTP basic authentication


## Author

support@ory.sh

